@@ -1014,7 +1014,38 @@ class IOSRouteLine(BaseIOSRouteLine):
 
 
 class IOSCfgLine(BaseCfgLine):
-    """Manage IOS Config line parent / child relationships"""
+    """An object for a parsed IOS-style configuration line.  
+       :class:`models_cisco.IOSCfgLine` objects contain references to other 
+       parent and child :class:`models_cisco.IOSCfgLine` objects.
+
+       .. note::
+
+          Originally, :class:`models_cisco.IOSCfgLine` objects were intended 
+          for advanced ciscoconfparse users.  As of ciscoconfparse 
+          version 0.9.10, all users are strongly encouraged to prefer the 
+          methods directly on :class:`models_cisco.IOSCfgLine` objects.  
+          Ultimately, if you write scripts which call methods on 
+          :class:`models_cisco.IOSCfgLine` objects, your scripts will be much 
+          more efficient than if you stick strictly to the classic 
+          :class:`ciscoconfparse.CiscoConfParse` methods.
+
+       Parameters
+       ----------
+
+       text : str, required
+            A string containing a text copy of the IOS configuration line.
+            :class:`ciscoconfparse.CiscoConfParse` will automatically identify 
+            the parent and children (if any) when it parses the configuration. 
+       comment_delimiter : str, required
+            A string which is considered a comment for the configuration 
+            format.  Since this is for Cisco IOS-style configurations, it 
+            defaults to ``!``.
+
+       Returns
+       -------
+
+       retval : an instance of :class:`models_cisco.IOSCfgLine`.
+    """
     ### Example of family relationships
     ###
     #Line01:policy-map QOS_1
